﻿using System;
using System.Windows;
using System.Windows.Media;

namespace Wp7nl.Utilities
{
  /// <summary>
  /// Class to help animations from code using the CompositeTransform
  /// </summary>
  public static class FrameworkElementExtensions2
  {
    /// <summary>
    /// Gets a double property from a framework element
    /// </summary>
    /// <param name="fe">FrameworkElement</param>
    /// <param name="property">DependencyProperty</param>
    /// <returns>Translation point</returns>
    public static double GetDoubleTransformProperty(this FrameworkElement fe, DependencyProperty property)
    {
      var translate = fe.GetCompositeTransform();
      if (translate == null) throw new ArgumentNullException("CompositeTransform");
      return (double)translate.GetValue(property);
    }

    /// <summary>
    /// Gets the ScaleX property from a framework element
    /// </summary>
    /// <param name="fe">FrameworkElement</param>
    /// <returns>Translation X</returns>
    public static double GetScaleXProperty(this FrameworkElement fe)
    {
      return fe.GetDoubleTransformProperty(CompositeTransform.ScaleXProperty);
    }

    /// <summary>
    /// Gets the ScaleY property from a framework element
    /// </summary>
    /// <param name="fe">FrameworkElement</param>
    /// <returns>Translation Y</returns>
    public static double GetScaleYProperty(this FrameworkElement fe)
    {
      return fe.GetDoubleTransformProperty(CompositeTransform.ScaleYProperty);
    }

    /// <summary>
    /// Gets the Opacity property from a framework element
    /// </summary>
    /// <param name="fe">FrameworkElement</param>
    /// <returns>Opacity</returns>
    public static double GetOpacityProperty(this FrameworkElement fe)
    {
      return (double)fe.GetValue(UIElement.OpacityProperty);
    }
  }
}
